@@ -3,11 +3,11 @@
 #' This function can be used to adjust the data for the effect of other variables present in the dataset. It is based on an underlying fitting of regressions models, allowing for quite some flexibility, such as including factors as random effects in mixed models (multilevel partialization), continuous variables as smooth terms in general additive models (non-linear partialization) and/or fitting these models under a Bayesian framework. The values returned by this function are the residuals of the regression models. Note that a regular correlation between two "adjusted" variables is equivalent to the partial correlation between them.
 #'
 #' @param data A dataframe.
-#' @param effect Character vector of column names to be adjusted for (regressed out). If \code{NULL} (the default), all variables will be selected.
+#' @param effect Character vector of column names to be adjusted for (regressed out). If `NULL` (the default), all variables will be selected.
 #' @inheritParams standardize
-#' @param multilevel If \code{TRUE}, the factors are included as random factors. Else, if \code{FALSE} (default), they are included as fixed effects in the simple regression model.
-#' @param additive If \code{TRUE}, continuous variables as included as smooth terms in additive models. The goal is to regress-out potential non-linear effects.
-#' @param bayesian If \code{TRUE}, the models are fitted under the Bayesian framework using \code{rstanarm}.
+#' @param multilevel If `TRUE`, the factors are included as random factors. Else, if `FALSE` (default), they are included as fixed effects in the simple regression model.
+#' @param additive If `TRUE`, continuous variables as included as smooth terms in additive models. The goal is to regress-out potential non-linear effects.
+#' @param bayesian If `TRUE`, the models are fitted under the Bayesian framework using `rstanarm`.
 #'
 #' @examples
 #' adjust(iris, effect = "Species", select = "Sepal.Length")
@@ -24,20 +24,25 @@
 #'
 #' @export
 adjust <- function(data, effect = NULL, select = NULL, exclude = NULL, multilevel = FALSE, additive = FALSE, bayesian = FALSE){
+  if (!all(colnames(data) == make.names(colnames(data), unique = TRUE))) {
+    warning("Bad column names (e.g., with spaces) have been detected which might create issues in many functions.\n",
+            "Please fix it (you can run `names(mydata) <- make.names(names(mydata))` for an automatic fix).",
+            call. = FALSE)
+  }
 
   # Find predictors
-  if(is.null(effect)){
+  if (is.null(effect)) {
     effect <- names(data)
   }
 
   # Factors
   formula_random <- NULL
   facs <- names(data[effect][!sapply(data[effect], is.numeric)])
-  if (length(facs) >= 1){
-    if(multilevel){
-      if(additive){
+  if (length(facs) >= 1) {
+    if (multilevel) {
+      if (additive) {
         formula_random <- as.formula(paste("~", paste(paste0("(1|", facs, ")"), collapse = " + ")))
-      } else{
+      } else {
         formula_random <- paste("+", paste(paste0("(1|", facs, ")"), collapse = " + "))
       }
       effect <- effect[!effect %in% facs]
@@ -46,25 +51,25 @@ adjust <- function(data, effect = NULL, select = NULL, exclude = NULL, multileve
 
   nums <- sapply(data, is.numeric)
   # Find outcomes
-  if(is.null(select)){
+  if (is.null(select)) {
     select <- names(data[nums])
   }
-  if(!is.null(exclude)){
+  if (!is.null(exclude)) {
     select <- select[!select %in% c(exclude)]
   }
 
   # Fit models
   out <- data.frame(.ID = 1:nrow(data))
-  for(var in select){
+  for (var in select) {
     predictors <- effect[effect != var]
-    if(additive){
+    if (additive) {
       predictors_num <- names(data[predictors][sapply(data[predictors], is.numeric)])
       predictors[predictors == predictors_num] <- paste0("s(", predictors_num, ")")
     }
     formula_predictors <- paste(c("1", predictors), collapse = " + ")
     formula <- paste(var, "~", formula_predictors)
 
-    x <- .model_adjust_for(data=data[unique(c(var, effect, facs))], formula, multilevel = multilevel, additive = additive, bayesian = bayesian, formula_random = formula_random)
+    x <- .model_adjust_for(data = data[unique(c(var, effect, facs))], formula, multilevel = multilevel, additive = additive, bayesian = bayesian, formula_random = formula_random)
     out[var] <- x
   }
   out[names(data)[!names(data) %in% names(out)]] <- data[names(data)[!names(data) %in% names(out)]]
@@ -79,9 +84,9 @@ adjust <- function(data, effect = NULL, select = NULL, exclude = NULL, multileve
 .model_adjust_for <- function(data, formula, multilevel = FALSE, additive = FALSE, bayesian = FALSE, formula_random = NULL) {
 
   # Additive -----------------------
-  if(additive){
+  if (additive) {
     # Bayesian
-    if(bayesian){
+    if (bayesian) {
       if (!requireNamespace("rstanarm")) {
         stop("This function needs `rstanarm` to be installed. Please install by running `install.packages('rstanarm')`.")
       }
@@ -97,7 +102,7 @@ adjust <- function(data, effect = NULL, select = NULL, exclude = NULL, multileve
   # Linear -------------------------
   } else{
     # Bayesian
-    if(bayesian){
+    if (bayesian) {
       if (!requireNamespace("rstanarm")) {
         stop("This function needs `rstanarm` to be installed. Please install by running `install.packages('rstanarm')`.")
       }
